"use client";
'use strict';

var tinyInvariant = require('./external/tiny-invariant/dist/esm/tiny-invariant.js');
var React = require('react');
var useRollbar = require('./useRollbar.js');

// Simple version does its job
// export function useRollbarContext(context) {
//   useRollbarConfiguration({ payload: { context }});
// }

// Complex version will set the context when part of the tree and reset back to original context when removed
function useRollbarContext() {
  var ctx = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
  var isLayout = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
  tinyInvariant.default(typeof ctx === 'string', '`ctx` must be a string');
  var rollbar = useRollbar.useRollbar();
  (isLayout ? React.useLayoutEffect : React.useEffect)(function () {
    var origCtx = rollbar.options.payload.context;
    rollbar.configure({
      payload: {
        context: ctx
      }
    });
    return function () {
      rollbar.configure({
        payload: {
          context: origCtx
        }
      });
    };
  }, [ctx]);
}

exports.useRollbarContext = useRollbarContext;
//# sourceMappingURL=useRollbarContext.js.map
